==> qtjambi-texttospeech-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiTextToSpeech/QTextToSpeech_shell.h <==
#ifndef QTEXTTOSPEECH_SHELL_H
#define QTEXTTOSPEECH_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtTextToSpeech/qtexttospeech.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtTextToSpeech/qvoice.h>
#include "hashes.h"
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QTextToSpeech_shell : public QTextToSpeech, public QtJambiShellInterface
{
public:
    QTextToSpeech_shell(QObject* parent0 = nullptr);
    QTextToSpeech_shell(const QString& engine0, QObject* parent1 = nullptr);
    ~QTextToSpeech_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextToSpeech_access : public QTextToSpeech
{
};

#endif // QTEXTTOSPEECH_SHELL_H

==> qtjambi-texttospeech-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiTextToSpeech/QTextToSpeech_shell.h <==
#ifndef QTEXTTOSPEECH_SHELL_H
#define QTEXTTOSPEECH_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtTextToSpeech/qtexttospeech.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtTextToSpeech/qvoice.h>
#include "hashes.h"
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QTextToSpeech_shell : public QTextToSpeech, public QtJambiShellInterface
{
public:
    QTextToSpeech_shell(QObject* parent0 = nullptr);
    QTextToSpeech_shell(const QString& engine0, const QMap<QString, QVariant>& params1, QObject* parent2 = nullptr);
    QTextToSpeech_shell(const QString& engine0, QObject* parent1 = nullptr);
    ~QTextToSpeech_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextToSpeech_access : public QTextToSpeech
{
};

#endif // QTEXTTOSPEECH_SHELL_H
